@@ -30,6 +30,11 @@ complete_levels <- function(x, character_levels = NULL) {
 
     # create padding
     if (length(vault) > 0) {
+        # HACK: Some models use a character variable with many levels (e.g.,
+        # mixed-effects groups). This creates a massive padding dataset, and making
+        # predictions can become very expensive.
+        if (isTRUE(sum(sapply(vault, length)) > 100)) return(data.frame())
+
         padding <- utils::head(x, 1)
         data.table::setDT(padding)
         for (v in names(vault)) {
