@@ -31,7 +31,7 @@ get_contrast_data <- function(model,
     } else {
         first_cross <- NULL
     }
-                                    
+
     # must use `as.data.table()` because `setDT()` does not handle columns with
     # more dimensions (e.g., "idx" in {mlogit})
     newdata <- as.data.table(newdata)
@@ -151,7 +151,7 @@ get_contrast_data <- function(model,
             original[[i]][[paste0("contrast_", names(original)[i])]] <- lab[[i]]
         }
 
-        fun <- function(x, y) merge(x, y, all = TRUE, allow.cartesian = TRUE)
+        fun <- function(x, y) merge(x, y, all = TRUE, allow.cartesian = TRUE, sort = FALSE)
         lo <- Reduce("fun", lo)
         hi <- Reduce("fun", hi)
         original <- Reduce("fun", original)
